@@ -1,6 +1,5 @@
 from django.conf import settings
 from django.contrib.sites.models import Site
-from django.contrib import messages
 from django.urls import reverse
 from django.utils.translation import ugettext as _
 from ryzom_django_mdc.html import *  # noqa
@@ -24,22 +23,14 @@ class Form(Form):
 
 
 class Container(Div):
-    sass = '''
-    .Container
-        display: flex
-        flex-direction: column
-        align-items: center
-        max-width: 960px
-        width: 96vw
-        margin: auto
-
-    .up-modal .Container
-        width: 86vw
-
-    @media screen and (max-width: 500px)
-        .up-modal .up-modal-content
-            padding: 10px
-    '''
+    style = {
+        'display': 'flex',
+        'flex-direction': 'column',
+        'align-items': 'center',
+        'max-width': '960px',
+        'width': '96vw',
+        'margin': 'auto',
+    }
 
 
 class FormContainer(Container):
@@ -48,17 +39,12 @@ class FormContainer(Container):
         max-width: 580px
         .mdc-text-field, .mdc-form-field, .mdc-select, form
             width: 100%
-            max-width: 90vw
     '''
 
 
 class PageMenu(Div):
     attrs = dict(cls='mdc-elevation--z2', style='margin-bottom: 10px')
 
-    def __init__(self, *args, _next=None, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._next = _next
-
     def to_html(self, *content, **context):
         if 'page-menu' not in context:
             return super().to_html(*content, **context)
@@ -70,11 +56,6 @@ class PageMenu(Div):
             if v.urlname == context['view'].urlname:
                 continue
 
-            href = v.url
-            if self._next:
-                if '?' not in href:
-                    href += '?'
-                href += '&_next=' + self._next
             button = A(
                 MDCTextButton(
                     v.label.capitalize(),
@@ -85,7 +66,7 @@ class PageMenu(Div):
                         'color': getattr(v, 'color', 'inherit'),
                     },
                 ),
-                href=href,
+                href=v.url,
                 style='text-decoration: none',
             )
             if getattr(v, 'controller', None) == 'modal':
@@ -106,93 +87,22 @@ class Main(Main):
     pass
 
 
-class ModalClose(Component):
-    '''
-    Close the modal when inserted by Unpoly.
-
-    This should be the default behaviour of Unpoly, as documented, and is the
-    case with modals that do not redirect on the same page, but for modals with
-    a form with a ?_next= redirection then surprisingly unpoly does update the
-    body but does not close the modal by default.
-
-    This tag registers a compiler that calls up.modal.close() when it
-    sees itself, given that unpoly does not execute scripts in
-    response that it loads. As such, this tag MUST be in the initial body, but
-    outside the elements that you will load in modal.
-
-    Remove this hack when we figure the problem in unpoly.
-
-    Equivalent of::
-
-        Script(
-            'up.compiler(".closemodal", function() { up.modal.close(); })',
-            cls='closemodal',
-        ),
-    '''
-    attrs = dict(cls='closemodal')
-
-    def py2js():
-        up.compiler('.closemodal', lambda: up.modal.close())
-
-
-class Message(MDCSnackBar):
-    icons = dict(
-        debug='check_circle',
-        info='check_circle',
-        success='check_circle',
-        warning='warning',
-        error='error',
-    )
-    colors = dict(
-        debug='green',
-        info='yellow',
-        success='green',
-        warning='orange',
-        error='red',
-    )
-    style = '''
-        padding-left: 16px;
-        display: flex;
-        flex-direction: row;
-        align-items: center
-    '''
-
-    def py2js(self):
-        return  # we will use up.compiler
-
-
-class Messages(Div):
-    def to_html(self, *content, **context):
-        msgs = messages.get_messages(context['view'].request)
-        if not msgs:
-            return ''
-
-        return Div(*[
-            Message(message)
-            for message in msgs
-        ]).to_html(*content, **context)
-
-
 class Body(Body):
     style = 'margin: 0'
 
     def __init__(self, *content, **attrs):
         self.drawer = mdcDrawer(id='drawer')
         self.bar = mdcTopAppBar()
-        self.main_inner = Div(
-            Messages(),
-            *content,
-            cls='main-inner',
-        )
         self.main = Main(
-            self.main_inner,
-            ModalClose(),
+            Div(
+                *content,
+                cls='main-inner',
+            ),
             cls='main mdc-drawer-app-content',
             id='main',
         )
         self.debug = settings.DEBUG
         super().__init__(
-            Spinner(),
             self.bar,
             Div(
                 self.drawer,
@@ -202,109 +112,24 @@ class Body(Body):
         )
 
     def py2js(self):
-        up.compiler(
-            '[data-mdc-auto-init]',
-            lambda el: mdc.autoInit(el.parentElement)
-        )
+        up.compiler('[data-mdc-auto-init]', lambda: mdc.autoInit())
         if self.debug:
             up.log.enable()
 
 
-class Spinner(Div):
-    sass = '''
-    .Spinner
-        position: fixed
-        float: right
-        z-index: 20000
-        cursor: pointer
-
-        right: -24px
-        top: 3px
-        @media only screen and (max-width: 600px)
-          top: -32px
-          top: 0
-
-        .lds-dual-ring
-          display: inline-block
-          width: 80px
-          height: 80px
-
-        .lds-dual-ring:after
-          content: " "
-          display: block
-          width: 28px
-          height: 28px
-          margin: 8px
-          border-radius: 50%
-          border: 6px solid #fff
-          border-color: var(--mdc-theme-primary) white var(--mdc-theme-primary) white
-          animation: lds-dual-ring 1.2s linear infinite
-
-        @keyframes lds-dual-ring
-          0%
-            transform: rotate(0deg)
-
-          100%
-            transform: rotate(360deg)
-    '''  # noqa
-
-    def py2js(self):
-        up.proxy.config.slowDelay = 25
-        up.compiler('.Spinner', lambda element: [
-            up.on('up:proxy:slow', lambda: up.element.show(element)),
-            up.on('up:proxy:recover', lambda: up.element.hide(element)),
-        ])
-
-    def __init__(self):
-        super().__init__(Div(cls='lds-dual-ring'), style='display:none')
-
-
-def poll():
-    def poll_setup(element):
-        if not element.getAttribute('id'):
-            console.error('[poll] *REQUIRES* an id attribute!')
-            return
-        interval = parseInt(element.getAttribute('poll') or 5000)
-
-        def poll():
-            if not document.hidden:
-                up.reload(element)
-        poll = setInterval(poll, interval)
-
-        def clear():
-            clearInterval(poll)
-        return clear
-    up.compiler('[poll]', poll_setup)
-
-
-def snack(self):
-    def open_snack(elem):
-        sb = new.mdc.snackbar.MDCSnackbar(elem)
-        sb.open()
-    up.compiler('[data-mdc-auto-init=MDCSnackbar]', open_snack)
-
-
 class App(Html):
     body_class = Body
     scripts = [
-        'https://unpkg.com/unpoly@1.0.0/dist/unpoly.js',
-        poll,
-        snack,
-        # 'https://unpkg.com/unpoly@2.0.0-rc9/unpoly.min.js',
-        # 'https://unpkg.com/unpoly@2.0.0-rc9/unpoly-migrate.js',
+        'https://unpkg.com/unpoly@0.62.1/dist/unpoly.js',
     ]
     stylesheets = [
-        'https://unpkg.com/unpoly@1.0.0/dist/unpoly.css',
-        # 'https://unpkg.com/unpoly@2.0.0-rc9/unpoly.min.css',
+        'https://unpkg.com/unpoly@0.62.1/dist/unpoly.min.css',
     ]
-    sass = '''
-    .up-modal .up-modal-viewport
-        padding-left: 0
-        padding-right: 0
-        padding-top: 10px
-    '''
 
     def to_html(self, *content, **context):
+        self.head.content.append(
+            Style('.up-modal-content { padding-top: 0; padding-bottom: 0; }')
+        )
         if title := getattr(context['view'], 'title', None):
             self.head.content.append(Title(title))
         return super().to_html(*content, **context)
@@ -339,24 +164,13 @@ class FormTemplate(FormContainer):
                 ),
                 href=next_,
             )
-
-        _next = view.request.GET.get(
-            '_next',
-            view.request.POST.get('_next', ''),
-        )
-        if _next:
-            _next = Input(type='hidden', name='_next', value=_next)
-
         return super().to_html(
             H3(view.title),
             Form(
                 form,
                 CSRFInput(view.request),
-                _next,
                 back,
                 MDCButtonRaised(getattr(view, 'title_submit', _('Submit'))),
-                method='post',
-                action=view.request.path_info,
             ),
         )
 
@@ -394,19 +208,12 @@ class Swagger(Div):
         )
 
 
-@template('crudlfap/home.html', App, Container)
+@template('crudlfap/home.html', App)
 class Home(Div):
     def to_html(self, **context):
         site = Site.objects.get_current()
         return super().to_html(
             H1('Welcome to ' + site.name),
-            MDCButtonRaised(
-                'Login to continue',
-                href=reverse('login'),
-                up_target=UNPOLY_TARGET_ALL,
-                tag='a',
-            ),
-            Div('Then, navigate with the menu button at the north west'),
             **context
         )
 
@@ -414,20 +221,21 @@ class Home(Div):
 @template('registration/logged_out.html', App, NarrowCard)
 class LoggedOut(Div):
     def to_html(self, **context):
+        from .site import site
         return super().to_html(
             H1(_('Log out')),
             P(_('Thanks for spending some quality time with the Web site today.')),  # noqa
             A(
                 _('Log in again'),
-                href=reverse('login'),
+                href=site.views['login'].url,
             ),
             **context,
         )
 
 
-@template('crudlfap/detail.html', App)
+@template('crudlfap/detail.html', App, NarrowCard)
 class ObjectDetail(Div):
-    def to_html(self, *content, **context):
+    def to_html(self, **context):
         table = MDCDataTable()
         table.thead.attrs.style.display = 'none'
         table.table.attrs.style.width = '100%'
@@ -439,12 +247,7 @@ class ObjectDetail(Div):
                 MDCDataTableTd(field['value']),
             ))
 
-        return super().to_html(
-            PageMenu(),
-            *content,
-            NarrowCard(table),
-            **context
-        )
+        return super().to_html(table, **context)
 
     def context(self, *content, **context):
         context['page-menu'] = context['view'].router.get_menu(
@@ -490,14 +293,13 @@ class ListActions(Component):
 @template('crudlfap/list.html', App)
 class ObjectList(Div):
     def context(self, *content, **context):
-        if 'page-menu' not in context:
-            context['page-menu'] = context['view'].router.get_menu(
-                'model',
-                context['view'].request,
-            )
+        context['page-menu'] = context['view'].router.get_menu(
+            'model',
+            context['view'].request,
+        )
         return super().context(*content, **context)
 
-    def to_html(self, *content, **context):
+    def to_html(self, **context):
         checkbox = None
         context['listactions'] = context['view'].router.get_menu(
             'list_action',
@@ -536,9 +338,8 @@ class ObjectList(Div):
         table.addchild(self.pagination_component(**context))
 
         return super().to_html(
-            *content,
             self.drawer_component(**context) or '',
-            PageMenu(_next=context['view'].request.path),
+            PageMenu(),
             Div(
                 self.search_component(**context) or '',
                 table,
@@ -910,26 +711,17 @@ class mdcTopAppBar(Header):
     def nav():
         window.drawer.open = not window.drawer.open
 
-    def close():
-        if window.visualViewport.width < 800:
-            window.drawer.open = False
-
     def py2js(self):
-        up.compiler('#drawer, #app-bar, #main', self.setup)
+        window.addEventListener('DOMContentLoaded', self.setup)
 
     def setup():
-        drawer = document.getElementById('drawer')
-        app_bar = document.getElementById('app-bar')
-        main = document.getElementById('main')
-
-        window.drawer = mdc.drawer.MDCDrawer.attachTo(drawer)
-        topAppBar = mdc.topAppBar.MDCTopAppBar.attachTo(app_bar)
-        topAppBar.setScrollTarget(main)
+        window.drawer = mdc.drawer.MDCDrawer.attachTo(
+            document.getElementById('drawer'))
+        topAppBar = mdc.topAppBar.MDCTopAppBar.attachTo(
+            document.getElementById('app-bar'))
+        topAppBar.setScrollTarget(document.getElementById('main'))
         topAppBar.listen('MDCTopAppBar:nav', self.nav)
 
-        for link in drawer.querySelectorAll('a'):
-            link.addEventListener('click', self.close)
-
 
 class mdcDrawer(Aside):
     menu_hooks = []
