@@ -26,13 +26,28 @@ class ActionsColumn(tables.Column):
 
     def render(self, record, table, value, **kwargs):
         from crudlfap.site import site
+        buttons = []
+        views = site[type(record)].get_menu(
+            'object',
+            table.request,
+            object=record
+        )
+        for view in views:
+            button = html.Component(
+                f'<button class="material-icons mdc-icon-button" ryzom-id="308bade28a8c11ebad3800e18cb957e9" style="color: {getattr(view, "color", "")}; --mdc-ripple-fg-size:28px; --mdc-ripple-fg-scale:1.7142857142857142; --mdc-ripple-left:10px; --mdc-ripple-top:10px;">{getattr(view, "icon", "")}</button>',  # noqa
+                title=view.title.capitalize(),
+                href=view.url + '?next=' + table.request.path_info,
+                style='text-decoration: none',
+                tag='a',
+            )
+            if getattr(view, 'controller', None) == 'modal':
+                button.attrs.up_modal = '.main-inner'
+            else:
+                button.attrs['up-target'] = html.A.attrs['up-target']
+            buttons.append(button)
         out = html.Div(
-            *site[type(record)].get_menu_component(
-                'object',
-                table.request,
-                object=record
-            ).content,
-            style='display:flex;flex-direction:row-reverse',
+            *buttons,
+            style='display:flex;flex-direction:row-reverse'
         ).render()
         return mark_safe(out)
 
@@ -54,23 +69,23 @@ class TableMixin(object):
         if self.table_sequence:
             self.table_fields = [
                 f.name
-                for f in self.object_list.model._meta.fields
+                for f in self.model._meta.fields
                 if f.name in self.table_sequence
             ]
         else:
             self.table_fields = [
                 f.name
-                for f in self.object_list.model._meta.fields
+                for f in self.model._meta.fields
                 if f.name not in self.exclude
             ]
         return self.table_fields
 
     def get_table_link_fields(self):
-        if not hasattr(self.object_list.model, 'get_absolute_url'):
+        if not hasattr(self.model, 'get_absolute_url'):
             return []
 
         for field in self.table_fields:
-            model_field = self.object_list.model._meta.get_field(field)
+            model_field = self.model._meta.get_field(field)
             if isinstance(model_field, models.CharField):
                 return [field]
 
@@ -94,7 +109,7 @@ class TableMixin(object):
         return dict()
 
     def get_table_meta_attributes(self):
-        attrs = dict(model=self.object_list.model)
+        attrs = dict(model=self.model)
 
         if self.table_sequence:
             attrs['sequence'] = self.table_sequence
@@ -134,7 +149,7 @@ class TableMixin(object):
             bases = (self.table_class, Table)
 
         return type(
-            '{}Table'.format(self.object_list.model.__name__),
+            '{}Table'.format(self.model.__name__),
             bases,
             self.table_class_attributes
         )
